@@ -5,10 +5,9 @@ from dataclasses import dataclass
 from functools import lru_cache
 from io import StringIO
 import logging
-from logging import Logger
 import math
 from pathlib import Path
-from typing import Dict, Iterable, List, Optional, Union
+from typing import Dict, Iterable, Union
 from zipfile import ZipFile, ZipInfo
 
 from fiona.io import ZipMemoryFile
@@ -17,10 +16,9 @@ from pkg_resources import resource_string
 from shapely import wkt
 from shapely.geometry import MultiPolygon, Point, Polygon
 import us
-from us.states import State
 
 # Initialize logger
-logger: Logger = logging.getLogger(__name__)
+logger = logging.getLogger(__name__)
 
 
 @dataclass
@@ -46,8 +44,8 @@ class Geo:
             self.code = code
 
         # Convert state abbreviation to FIPS code as needed
-        if self.type == 'state':
-            state: State = us.states.lookup(self.code)
+        if (self.type == 'state') and (code != '*'):
+            state = us.states.lookup(self.code)
             if state is not None:
                 self.code = state.fips
 
@@ -57,39 +55,39 @@ class Geo:
 
 def calculate_congress_number(year: int) -> int:
     """Given a year, calculate the number of the U.S. Congress."""
-    congress: int = math.ceil((year - 1789) / 2) + 1
+    congress = math.ceil((year - 1789) / 2) + 1
     return congress
 
 
 @lru_cache(maxsize=1024)
 def get_geo_mappings(source: str) -> Dict[str, str]:
     """Read filename codes from a local CSV."""
-    codes_csv: bytes = resource_string(__name__, f'resources/{source}.csv')
-    csv_reader: Iterable[List[str]] = reader(StringIO(codes_csv.decode('utf-8')))
+    codes_csv = resource_string(__name__, f'resources/{source}.csv')
+    csv_reader = reader(StringIO(codes_csv.decode('utf-8')))
     codes = {type_: code for type_, code in csv_reader}
     return codes
 
 
-def determine_gazetteer_code(year: int, for_geo_type: str) -> Optional[str]:
+def determine_gazetteer_code(year: int, for_geo_type: str) -> Union[str, None]:
     """Determine the Gazetteer file naming code for a given year/geography."""
-    gazetteer_codes: Dict[str, str] = get_geo_mappings('gazetteer_codes')
-    gazetteer_code: Optional[str]
+    gazetteer_codes = get_geo_mappings('gazetteer_codes')
+    gazetteer_code: Union[str, None]
     if for_geo_type != 'congressional district':
         gazetteer_code = gazetteer_codes.get(for_geo_type)
     else:
-        congress: int = calculate_congress_number(year)
+        congress = calculate_congress_number(year)
         gazetteer_code = gazetteer_codes[for_geo_type].format(congress=congress)
     return gazetteer_code
 
 
 def determine_geo_code(year: int, for_geo_type: str, state_fips: str) -> str:
     """Determine the shapefile naming code for a given year/geography."""
-    geo_codes: Dict[str, str] = get_geo_mappings('geo_codes')
+    geo_codes = get_geo_mappings('geo_codes')
     geo_code: str
     if for_geo_type != 'congressional district':
         geo_code = geo_codes[for_geo_type].format(state_fips=state_fips)
     else:
-        congress: int = calculate_congress_number(year)
+        congress = calculate_congress_number(year)
         geo_code = geo_codes[for_geo_type].format(congress=congress)
     return geo_code
 
@@ -108,7 +106,7 @@ def load_geodataframe(filepath: Path) -> GeoDataFrame:
     """
     # Get .shp filename from within zipped shapefile
     with ZipFile(filepath, 'r') as zip_file:
-        shp_filename: str = next(filter(is_shp_file, zip_file.filelist)).filename
+        shp_filename = next(filter(is_shp_file, zip_file.filelist)).filename
 
     # Use default Python opener to prevent cryptic GDAL filepath errors
     with open(filepath, 'rb') as bytes_file:
@@ -134,7 +132,7 @@ def coerce_polygon_to_multipolygon(shape: Union[MultiPolygon, Polygon]) -> Multi
 def flatten_geometry(multipolygon: MultiPolygon) -> MultiPolygon:
     """Flatten a three-dimensional multipolygon to two dimensions."""
     try:
-        has_z: bool = multipolygon.has_z
+        has_z = multipolygon.has_z
     except AttributeError:
         return multipolygon
     else:
@@ -164,19 +162,19 @@ def identify_affgeoid_field(fields: Iterable[str]) -> str:
     merging geospatial data with table data.
     """
     known_field_names = {'AFFGEOID', 'AFFGEOID10'}
-    affgeoid_field: str = (known_field_names & set(fields)).pop()
+    affgeoid_field = (known_field_names & set(fields)).pop()
     return affgeoid_field
 
 
 @lru_cache(maxsize=1024)
-def normalize_geo_id(geo_id: str, geo_type: str) -> Optional[str]:
+def normalize_geo_id(geo_id: str, geo_type: str) -> Union[str, None]:
     """Convert a Census geographic identifier to a common format.
 
     This enables joins between entities like Gazetteer tables and ACS
     tables.
     """
-    geo_id_mappings: Dict[str, str] = get_geo_mappings('geo_ids')
-    template: Optional[str] = geo_id_mappings.get(geo_type)
+    geo_id_mappings = get_geo_mappings('geo_ids')
+    template = geo_id_mappings.get(geo_type)
     if template is None:
         return None
     return template.format(geo_id=geo_id)
